==> dotcloud.cli-0.2.3.tar.gz: dotcloud.cli-0.2.3/dotcloud/setup.py <==
## Copyright (c) 2010 dotCloud Inc.
##
## Permission is hereby granted, free of charge, to any person obtaining a copy
## of this software and associated documentation files (the "Software"), to deal
## in the Software without restriction, including without limitation the rights
## to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
## copies of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
## AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
## OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
## THE SOFTWARE.

from setuptools import setup

VERSION = '0.2.3'

# rm -rf build dist *.egg-info && python ./setup.py clean sdist upload -r pypi

setup(
        name                = 'dotcloud',
        version             = VERSION,
        author              = 'DotCloud inc.',
        author_email        = 'support@dotcloud.com',
        url                 = 'http://www.dotcloud.com',
        description         = 'DotCloud meta-package',
        install_requires    = ['dotcloud.cli >= {0}'.format(VERSION)],
        zip_safe            = False
)

==> dotcloud.cli-0.2.4.tar.gz: dotcloud.cli-0.2.4/dotcloud/setup.py <==
## Copyright (c) 2010 dotCloud Inc.
##
## Permission is hereby granted, free of charge, to any person obtaining a copy
## of this software and associated documentation files (the "Software"), to deal
## in the Software without restriction, including without limitation the rights
## to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
## copies of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
## AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
## OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
## THE SOFTWARE.

from setuptools import setup

VERSION = '0.2.4'

# rm -rf build dist *.egg-info && python ./setup.py clean sdist upload -r pypi

setup(
        name                = 'dotcloud',
        version             = VERSION,
        author              = 'DotCloud inc.',
        author_email        = 'support@dotcloud.com',
        url                 = 'http://www.dotcloud.com',
        description         = 'DotCloud command line interface',
        install_requires    = ['dotcloud.cli >= {0}'.format(VERSION)],
        zip_safe            = False
)
